{ username, pkgs, ... }:

{
  environment.systemPackages = with pkgs; [
    tor-browser
  ];

  environment.persistence."/nix/config" = {
    users."${username}".directories = [
      ".config/mozilla"
    ];
  };

  programs.firefox = {
    enable = true;
    package = pkgs.firefox-esr-wrapped;
    policies = {
      EnableTrackingProtection = {
        Value = true;
        Cryptomining = true;
        Fingerprinting = true;
        EmailTracking = true;
        Level = "strict";
      };
      DisableTelemetry = true;
      DisablePocket = true;
      DisableFirefoxStudies = true;
      DisableFirefoxAccounts = false;
      DisableAccounts = false;
      DontCheckDefaultBrowser = true;
      OverrideFirstRunPage = "";
      OverridePostUpdatePage = "";
      NoDefaultBookmarks = true;
      Cookies = {
        Behaviour = "reject-foreign";
        BehaviourPrivateBrowsing = "reject-foreign";
      };

      UserMessaging = {
        WhatsNew = false;
        ExtensionRecommendations = false;
        FeatureRecommendations = false;
        UrlbarInterventions = false;
        SkipOnboarding = true;
        MoreFromMozilla = false;
      };
      
      FirefoxHome = {
        Search = true;
        TopSites = true;
        SponsoredTopSites = false;
        Highlights = false;
        Pocket = false;
        SponsoredPocket = false;
        Snippets = false;
        Locked = true;
      };

      SearchSuggestEnabled = false;
      ShowSearchSuggestionsFirst = false;
      NewTabPage = false;

      SearchEngines = { # ESR only
        Add = [
          {
            Name = "Kagi";
            URLTemplate = "https://kagi.com/search?q={searchTerms}";
            Method = "GET";
            IconURL = "https://kagi.com/favicon.ico";
            Alias = "@k";
            Default = true;
          }
        ];
        Remove = [ "Bing" "Google" "DuckDuckGo" "Wikipedia (en)" ];
      };
    };
  };
}
